import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleOrdinal,
  schemeCategory10
} from 'd3';

import { dropDownMenu } from './dropDownMenu';
import { scatterPlot } from './scatterPlot';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const margin = { top: 10, right: 45, bottom: 250, left: 45 };

const color = scaleOrdinal(schemeCategory10);
const cValue = 9;

let data;
let xColumn;
let yColumn;
let selectedLegend;

const onXColumnClicked = column => {
  xColumn = column;  
  render();
};

const onYColumnClicked = column => {
  yColumn = column;  
  render();
};

const onClick = d => {
  selectedLegend = d;
  console.log({selectedLegend});
  render();
};

const scatterG = svg.append('g')
  .attr('transform', 
        `translate(${margin.left},
         ${margin.top})`);

var tipMouseover = function (d) {
   var html = 
    "<span style='color:" + color[cValue] + ";'>" + "</span><br/>" +
    "<b>" + d[xColumn] + `</b> ${xColumn}, <b/>` + d[yColumn] + `</b> ${yColumn}`;
  
  select('.tooltip').html(html)
    .style("left", (d3.event.pageX + 15) + "px")
    .style("top", (d3.event.pageY - 28) + "px")
    .transition()
    .duration(200) 
    .style("opacity", .9)
  
};

// tooltip mouseout event handler
var tipMouseout = function (d) {
  select('.tooltip').transition()
    .duration(300) 
    .style("opacity", 0);
};

const list = ['world_happiness_score',
              'gdp_per_capita',
              'employment_rate', 
              'government_effectiveness',
              'sustainable_economic_development_assessment', 
              'health_expenditure_per_person',
              'women_mps_pct',
              'control_of_corruption' 
             ];
const render = () => {  
  select('#x-menu')
    .call(dropDownMenu, {
      options: data.columns.filter(column =>
        column !== yColumn && list.includes(column)
      ),
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
      });
  
  select('#y-menu')
    .call(dropDownMenu, {
      options: data.columns.filter(column =>
        column !== xColumn && list.includes(column)
      ),
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
      });
  
  scatterG.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    circleRadius: 4,
    yAxisLabel: yColumn,
    margin: margin,
    width,
    height,
    data,
    cValue
  });
  
  
  select('body').append("div")
    .attr("class", "tooltip")
    .style("opacity", 0);

};

csv('https://gist.githubusercontent.com/mkt-ds/640984c80835e2823c1b0f5c9a3fabe6/raw/25ab8758703a8fad1f012fcc2319d7570037a663/happiness_byCountry.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d['world_happiness_score'] = +d['world_happiness_score'];
      d['gdp_per_capita'] = +d['gdp_per_capita'];
      d['sustainable_economic_development_assessment'] = +d['sustainable_economic_development_assessment'];
      d['employment_rate'] = +d['employment_rate'];
      d['health_expenditure_per_person'] = +d['health_expenditure_per_person'];
      d['government_effectiveness'] = +d['government_effectiveness'];
      d['women_mps_pct'] = +d['women_mps_pct'];
      d['control_of_corruption'] = +d['control_of_corruption'];
    });
    xColumn = data.columns[9];
    yColumn = data.columns[6];
    render();
});

